Performs the fitting process for the VO2 kinetics analysis. At this point, the data should already have been cleaned (outliers removed) and processed (interpolated, time-aligned, ensembled-averaged, and bin-averaged).
perform_kinetics(
.data_processed,
intensity_domain = c("moderate", "heavy", "severe"),
fit_level = 0.95,
fit_phase_1_length,
fit_baseline_length,
fit_transition_length,
verbose = TRUE,
...
)a tibble containing one row and the nested columns:
The data containing the time and VO2 columns, as well as the fitted data and its residuals for each data point.
A nls object. The model used in the VO2 kinetics fitting.
The tidied summary of the model.
The residuals of the model.
The final plot of the fitted model.
The residuals plot for the model diagnostics.
The data retrieved from process_data().
The exercise-intensity domain that the test was performed. Either moderate, heavy, or severe.
A numeric scalar between 0 and 1 giving the confidence level for the parameter estimates in the final VO2 kinetics fit. Default to 0.95.
The length of the phase I that you wish to exclude from the final exponential fit, in seconds. See VO2 kinetics section in ?vo2_kinetics for more details.
The length the baseline to perform the final linear fit, in seconds. See VO2 kinetics section ?vo2_kinetics for more details.
The length of the transition to perform the final exponential fit, in seconds. See VO2 kinetics section ?vo2_kinetics for more details.
A boolean indicating whether messages should be printed in the console. Default to TRUE.
Additional arguments when fitting VO2 kinetics in the heavy- or severe-intensity domains. Arguments may be the following:
TODO
See ?vo2_kinetics for details.